@@ -45,6 +45,7 @@ class Datasets(object):
             source_options=kwargs.get("source_options"),
             provider=kwargs.get("provider"),
             disk_size=kwargs.get("disk_size"),
+            project_uuid=self.trainml.active_project,
         )
         payload = {k: v for k, v in data.items() if v}
         logging.info(f"Creating Dataset {name}")
@@ -183,7 +184,11 @@ class Dataset:
             )
         if self.status == status:
             return
-        POLL_INTERVAL = 5
+        POLL_INTERVAL_MIN = 5
+        POLL_INTERVAL_MAX = 60
+        POLL_INTERVAL = max(
+            min(timeout / 60, POLL_INTERVAL_MAX), POLL_INTERVAL_MIN
+        )
         retry_count = math.ceil(timeout / POLL_INTERVAL)
         count = 0
         while count < retry_count:
