@@ -96,6 +96,7 @@ class Jobs(object):
             model=model,
             endpoint=endpoint,
             source_job_uuid=kwargs.get("source_job_uuid"),
+            project_uuid=self.trainml.active_project,
         )
         payload = {
             k: v
@@ -414,7 +415,12 @@ class Job:
             and self.status == "stopped"
         ):
             return
-        POLL_INTERVAL = 5
+
+        POLL_INTERVAL_MIN = 5
+        POLL_INTERVAL_MAX = 60
+        POLL_INTERVAL = max(
+            min(timeout / 60, POLL_INTERVAL_MAX), POLL_INTERVAL_MIN
+        )
         retry_count = math.ceil(timeout / POLL_INTERVAL)
         count = 0
         while count < retry_count:
